package com.ruoyi.ai.service;

import java.util.List;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ruoyi.ai.domain.AiTemplate;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;

/**
 * AI模版Service接口
 * 
 * @author shi
 * @date 2026-01-15
 */
public interface IAiTemplateService {

    /**
     * 查询AI模版
     * 
     * @param id AI模版主键
     * @return AI模版
     */
    AiTemplate selectAiTemplateById(Long id);

    /**
     * 查询AI模版列表
     * 
     * @param aiTemplate AI模版
     * @return AI模版集合
     */
    List<AiTemplate> selectAiTemplateList(AiTemplate aiTemplate);

    /**
     * 分页查询AI模版列表
     *
     * @param aiTemplate AI模版
     * @return AI模版集合
     */
    IPage<AiTemplate> selectAiTemplatePage(Page page, AiTemplate aiTemplate);

    /**
     * 新增AI模版
     * 
     * @param aiTemplate AI模版
     * @return 结果
     */
    int insertAiTemplate(AiTemplate aiTemplate);

    /**
     * 修改AI模版
     * 
     * @param aiTemplate AI模版
     * @return 结果
     */
    int updateAiTemplate(AiTemplate aiTemplate);

    /**
     * 批量删除AI模版
     * 
     * @param ids 需要删除的AI模版主键集合
     * @return 结果
     */
    int deleteAiTemplateByIds(Long[] ids);

    /**
     * 删除AI模版信息
     * 
     * @param id AI模版主键
     * @return 结果
     */
    int deleteAiTemplateById(Long id);
}
